@@ -58,9 +58,10 @@ class NumericPreModelAnalysis:
         X = pipeline.fit_transform(X)
         scaler = StandardScaler()
         X = scaler.fit_transform(X)
-
-        X_tsne_3d = TSNE(n_components=3).fit_transform(X)
-        X_tsne_2d = X_tsne_3d[:, :2]
+        try:
+            X_tsne_2d = TSNE(n_components=2).fit_transform(X)
+        except:
+            X_tsne_2d = TSNE(n_components=2, perplexity=10).fit_transform(X)
         fig = plt.figure(figsize=(12, 12))
         # ax1 = fig.add_subplot(121)
         ax1 = plt
@@ -68,7 +69,6 @@ class NumericPreModelAnalysis:
 
         if self.data_info.problem_type_val in ["Regression"]:
             ax1.scatter(X_tsne_2d[:, 0], X_tsne_2d[:, 1], c=target, cmap='viridis')
-            # ax2.scatter(X_tsne_3d[:, 0], X_tsne_3d[:, 1], X_tsne_3d[:, 2], c=self.target, cmap='viridis')
             ax1.title("Visualizing Numerical Features and Target with t-SNE (2D)")
             # ax2.set_title("Visualizing Numerical Features and Target with t-SNE (3D)")
         elif self.data_info.problem_type_val in ["Binary regression", "Binary classification"]:
@@ -76,11 +76,9 @@ class NumericPreModelAnalysis:
             color_map = {target_class: color for target_class, color in zip(target_classes, ['red', 'blue'])}
             colors = target.apply(lambda x: color_map[x])
             ax1.scatter(X_tsne_2d[:, 0], X_tsne_2d[:, 1], c=colors)
-            # ax2.scatter(X_tsne_3d[:, 0], X_tsne_3d[:, 1], X_tsne_3d[:, 2], c=colors)
             legend_handles = [Patch(color=color_map[target_class], label=target_class) for target_class in
                               target_classes]
             ax1.title("Visualizing Numerical Features and Target with t-SNE (2D)")
-            # ax2.set_title("Visualizing Numerical Features and Target with t-SNE (3D)")
             ax1.legend(handles=legend_handles)
         else:  # Multi-class classification
             target = target.astype(str)
@@ -92,11 +90,9 @@ class NumericPreModelAnalysis:
             except:
                 colors = target.apply(lambda x: color_map[str(x)])
             plt.scatter(X_tsne_2d[:, 0], X_tsne_2d[:, 1], c=colors)
-            # ax2.scatter(X_tsne_3d[:, 0], X_tsne_3d[:, 1], X_tsne_3d[:, 2], c=colors)
             legend_handles = [Patch(color=color_map[target_class], label=target_class) for target_class in
                               target_classes]
             ax1.title("Visualizing Numerical Features and Target with t-SNE (2D)")
-            # ax2.set_title("Visualizing Numerical Features and Target with t-SNE (3D)")
             ax1.legend(handles=legend_handles)
         plt.show()
         plt.close()
@@ -208,7 +204,7 @@ class NumericPreModelAnalysis:
         :param title: Title of the plot.
         :return: None.
         """
-        features_pvalues = [(feature, 1 - pvalue) for feature, pvalue in features_pvalues]
+        features_pvalues = [(feature, 1 - pvalue + 0.00001) for feature, pvalue in features_pvalues]
         wordcloud = WordCloud(width=900, height=500). \
             generate_from_frequencies(dict(features_pvalues))
         plt.title(title, fontsize=15)
@@ -308,13 +304,12 @@ class NumericPreModelAnalysis:
 
     def run(self, plot=True):
         if self.n_cols > 1:
-            pass
-            #     self.analyze_pvalue(is_plot=plot)
-            #     if ('classification' in self.data_info.problem_type_val.lower()) and plot:
-            #         self.partial_plot(classification_row_percent=True)
-            #         self.partial_plot(classification_row_percent=False)
-            #     else:
-            #         self.partial_plot()
+            self.analyze_pvalue(is_plot=plot)
+            if ('classification' in self.data_info.problem_type_val.lower()) and plot:
+                self.partial_plot(classification_row_percent=True)
+                self.partial_plot(classification_row_percent=False)
+            else:
+                self.partial_plot()
             self.tsne()
         elif self.n_cols == 1:
             self.analyze_pvalue()
