@@ -3,6 +3,7 @@ import nltk
 import pandas as pd
 import seaborn as sns
 
+from chester.run.user_classes import TextSummary
 from chester.util import ReportCollector, REPORT_PATH
 
 
@@ -83,7 +84,9 @@ class TextAnalyzer:
                  ner_extraction: bool = True, kewords_extraction: bool = True,
                  data_quality: bool = True, corex_topics_num: int = 10, corex_anchor_words=None,
                  corex_anchor_strength=1.6,
-                 top_words: int = 10, n_sentences: int = 5):
+                 top_words: int = 10, n_sentences: int = 5,
+                 text_summary: TextSummary = None,
+                 chester_collector=None):
         self.df = df
         self.create_wordcloud = create_wordcloud
         self.corex_topics = corex_topics
@@ -99,3 +102,5 @@ class TextAnalyzer:
         self.top_words = top_words
         self.n_sentences = n_sentences
         self.text_column = text_column
+        self.text_summary = text_summary
+        self.chester_collector = chester_collector or {}
