@@ -1,16 +1,8 @@
-from diamond.data_augmentation.augmentation import ImageAugmentation
-from diamond.image_caption.image_caption_class import ImageDescription
-from diamond.image_object_detection.image_object_class import ImageObjectDetection
-from diamond.model_training.best_model import ImageModelsTraining
-from diamond.post_model_analysis.post_model import ImagePostModelAnalysis
-from diamond.user_classes import ImagesData, ImagesAugmentationInfo, ImageModels, ImagePostModelSpec, \
-    ImageDescriptionSpec
-
-from diamond.utils import index_labels
+from diamond import run as diamond_run
 from vis.grayscale.grayscale import VideoToGrayScale
+from vis.object_video_tracker.object_tracker import ObjectVideoTracker
 from vis.reversed_order.video_revereser import VideoReverser
 from vis.user_classes import VideoData
-from diamond import run as diamond_run
 from vis.video_zoom.zoom_class import VideoZoomer
 
 
@@ -20,6 +12,7 @@ def run(video,
         plot=True,
         get_frames_description=False,
         detect_frame_objects=False,
+        detect_video_objects=False,
         detect_faces=False,
         get_grayscale=False,
         get_reveresed_video=False,
@@ -28,6 +21,10 @@ def run(video,
         ):
     vis_collector = {}
 
+    ## pre
+    if detect_video_objects:
+        detect_frame_objects = True
+
     video_data = VideoData(cap=video, image_shape=image_shape, frame_per_second=frame_per_second)
     vis_collector["video_data"] = video_data
 
@@ -57,4 +54,11 @@ def run(video,
 
     vis_collector.update(diamond_collector)
 
+    if detect_video_objects:
+        images = video_data.images
+        object_bounding_box = vis_collector["object detection"]
+        video_object_detector = ObjectVideoTracker(images=images, object_bounding_box=object_bounding_box,
+                                                   fps=video_data.frame_per_second)
+        video_object_detector.play()
+
     return vis_collector
